@@ -8,10 +8,13 @@ import (
 	"strings"
 
 	"github.com/derailed/popeye/internal/report"
-	"github.com/derailed/popeye/pkg"
 	"github.com/spf13/cobra"
 )
 
+func init() {
+	rootCmd.AddCommand(versionCmd())
+}
+
 func versionCmd() *cobra.Command {
 	return &cobra.Command{
 		Use:   "version",
@@ -28,7 +31,6 @@ func printVersion() {
 	printTuple("Version", version)
 	printTuple("Commit", commit)
 	printTuple("Date", date)
-	printTuple("Logs", pkg.LogFile)
 }
 
 func printTuple(section, value string) {
