@@ -1,10 +1,15 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of Popeye
+
 package cache
 
 import (
-	netv1 "k8s.io/api/networking/v1"
+	"errors"
 	"sync"
 
 	"github.com/derailed/popeye/internal"
+	"github.com/derailed/popeye/internal/db"
+	netv1 "k8s.io/api/networking/v1"
 )
 
 // IngressKey tracks Ingress resource references
@@ -12,26 +17,29 @@ const IngressKey = "ing"
 
 // Ingress represents Ingress cache.
 type Ingress struct {
-	ings map[string]*netv1.Ingress
+	db *db.DB
 }
 
 // NewIngress returns a new Ingress cache.
-func NewIngress(ings map[string]*netv1.Ingress) *Ingress {
-	return &Ingress{ings: ings}
-}
-
-// ListIngresses returns all available Ingresss on the cluster.
-func (d *Ingress) ListIngresses() map[string]*netv1.Ingress {
-	return d.ings
+func NewIngress(db *db.DB) *Ingress {
+	return &Ingress{db: db}
 }
 
 // IngressRefs computes all ingress external references.
-func (d *Ingress) IngressRefs(refs *sync.Map) {
-	for _, ing := range d.ings {
+func (d *Ingress) IngressRefs(refs *sync.Map) error {
+	txn, it := d.db.MustITFor(internal.Glossary[internal.ING])
+	defer txn.Abort()
+	for o := it.Next(); o != nil; o = it.Next() {
+		ing, ok := o.(*netv1.Ingress)
+		if !ok {
+			return errors.New("expected ing")
+		}
 		for _, tls := range ing.Spec.TLS {
 			d.trackReference(refs, ResFqn(SecretKey, FQN(ing.Namespace, tls.SecretName)))
 		}
 	}
+
+	return nil
 }
 
 func (d *Ingress) trackReference(refs *sync.Map, key string) {
