@@ -6,7 +6,7 @@ package lint
 import (
 	"context"
 
-	"github.com/Masterminds/semver"
+	"github.com/blang/semver/v4"
 	"github.com/derailed/popeye/internal"
 	"github.com/derailed/popeye/internal/issues"
 )
@@ -49,8 +49,8 @@ func (c *Cluster) checkVersion(ctx context.Context) error {
 		return err
 	}
 
-	ctx = internal.WithSpec(ctx, specFor("Version", nil))
-	if rev.Major() != tolerableMajor || rev.Minor() < tolerableMinor {
+	ctx = internal.WithSpec(ctx, SpecFor("Version", nil))
+	if rev.Major != tolerableMajor || rev.Minor < tolerableMinor {
 		c.AddCode(ctx, 405)
 	} else {
 		c.AddCode(ctx, 406)
