@@ -178,7 +178,7 @@ func (p *Popeye) Lint() (int, int, error) {
 			}
 		case config.IsStrSet(p.flags.S3.Bucket):
 			asset := filepath.Join(p.clusterPath(), p.scanFileName())
-			if err := p.flags.S3.Upload(asset, p.outputTarget); err != nil {
+			if err := p.flags.S3.Upload(context.Background(), asset, p.fileContentType(), p.outputTarget); err != nil {
 				log.Fatal().Msgf("S3 upload failed: %s", err)
 			}
 		}
@@ -202,11 +202,12 @@ func (p *Popeye) buildCtx(ctx context.Context) context.Context {
 	}
 	ns, err := p.client().Config().CurrentNamespaceName()
 	if err != nil {
+		log.Warn().Msgf("Unable to determine current namespace: %v. Using `default` namespace", err)
 		ns = client.DefaultNamespace
 	}
-	ctx = context.WithValue(ctx, internal.KeyNamespace, ns)
+	ctx = context.WithValue(ctx, internal.KeyNamespaceName, ns)
 
-	return ctx
+	return context.WithValue(ctx, internal.KeyNamespace, ns)
 }
 
 func (p *Popeye) validateSpinach(ss scrub.Scrubs) error {
@@ -226,10 +227,6 @@ func (p *Popeye) lint() (int, int, error) {
 		log.Debug().Msgf("Lint %v", time.Since(t))
 	}(time.Now())
 
-	ctx, cancel := context.WithCancel(context.Background())
-	defer cancel()
-	ctx = p.buildCtx(ctx)
-
 	codes, err := issues.LoadCodes()
 	if err != nil {
 		return 0, 0, err
@@ -250,22 +247,19 @@ func (p *Popeye) lint() (int, int, error) {
 	if err := p.validateSpinach(scrubers); err != nil {
 		return 0, 0, err
 	}
+
+	ctx := p.buildCtx(context.Background())
+	sections, ans := p.config.Sections(), p.client().ActiveNamespace()
+	nsGVR := types.NewGVR("v1/namespaces")
 	for k, fn := range scrubers {
 		gvr, ok := internal.Glossary[k]
-		if !ok || gvr == types.BlankGVR {
+		if !ok || gvr == types.BlankGVR || p.aliases.Exclude(gvr, sections) {
 			continue
 		}
-
-		if p.aliases.Exclude(gvr, p.config.Sections()) {
+		if gvr.String() != nsGVR.String() && client.IsNamespaced(ans) && !p.aliases.IsNamespaced(gvr) {
 			continue
 		}
-		// Skip node linter if active namespace is set.
-		if gvr == internal.Glossary[internal.NO] && p.client().ActiveNamespace() != client.AllNamespaces {
-			continue
-		}
-
 		runners[gvr] = fn(ctx, cache, codes)
-
 	}
 
 	total, errCount := len(runners), 0
@@ -304,12 +298,10 @@ func (p *Popeye) runLinter(ctx context.Context, gvr types.GVR, l scrub.Linter, c
 		}
 	}()
 
-	callCtx := ctx
 	if !p.aliases.IsNamespaced(gvr) {
-		callCtx = context.WithValue(ctx, internal.KeyNamespace, client.ClusterScope)
+		ctx = context.WithValue(ctx, internal.KeyNamespace, client.ClusterScope)
 	}
-
-	if err := l.Lint(callCtx); err != nil {
+	if err := l.Lint(ctx); err != nil {
 		p.builder.AddError(err)
 	}
 	o := l.Outcome().Filter(rules.Level(p.config.LintLevel))
@@ -551,3 +543,20 @@ func (p *Popeye) fileExt() string {
 		return "txt"
 	}
 }
+
+func (p *Popeye) fileContentType() string {
+	switch *p.flags.Output {
+	case "junit":
+		// https://datatracker.ietf.org/doc/html/rfc7303#section-4.1
+		return "application/xml"
+	case "json":
+		return "application/json"
+	case "yaml":
+		// https://datatracker.ietf.org/doc/html/rfc9512
+		return "application/yaml"
+	case "html":
+		return "text/html"
+	default:
+		return "text/plain"
+	}
+}
